@@ -1,5 +1,6 @@
 //! This module contains the config specification and functionality for creating a config.
 
+use clap::ValueEnum;
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 use std::{env, fs, io};
@@ -36,10 +37,13 @@ impl Config {
         let home = dirs::home_dir().ok_or(ConfigError::HomeDirNotFound)?;
         let path = home.join(".config").join("gfold.toml");
         let entry_config = match fs::read_to_string(path) {
-            Ok(contents) => match contents.is_empty() {
-                true => EntryConfig::default(),
-                false => toml::from_str(&contents)?,
-            },
+            Ok(contents) => {
+                if contents.is_empty() {
+                    EntryConfig::default()
+                } else {
+                    toml::from_str(&contents)?
+                }
+            }
             Err(e) => match e.kind() {
                 io::ErrorKind::NotFound => EntryConfig::default(),
                 _ => return Err(e.into()),
@@ -101,7 +105,7 @@ struct EntryConfig {
 /// In summary, while this setting is primarily for cosmetics, it may also affect runtime
 /// performance based on what needs to be displayed.
 #[remain::sorted]
-#[derive(Serialize, Deserialize, Clone, Copy)]
+#[derive(Serialize, Deserialize, Clone, Copy, ValueEnum)]
 pub enum DisplayMode {
     /// Informs the caller to display results in the classic format.
     Classic,
@@ -115,21 +119,9 @@ pub enum DisplayMode {
     StandardAlphabetical,
 }
 
-impl DisplayMode {
-    pub fn from_str(input: impl AsRef<str>) -> Option<Self> {
-        match input.as_ref() {
-            "classic" => Some(Self::Classic),
-            "json" => Some(Self::Json),
-            "standard" | "default" => Some(Self::Standard),
-            "standard-alphabetical" => Some(Self::StandardAlphabetical),
-            _ => None,
-        }
-    }
-}
-
 /// Set the color mode of results printed to `stdout`.
 #[remain::sorted]
-#[derive(Serialize, Deserialize, Clone, Copy)]
+#[derive(Serialize, Deserialize, Clone, Copy, ValueEnum)]
 pub enum ColorMode {
     /// Attempt to display colors as intended (default behavior).
     Always,
